@@ -46,7 +46,7 @@ permMMFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
       return(results)
     }
     #check input validity
-    if (xIndex < 0 || csIndex < 0) {
+    if ( any(xIndex < 0) || any(csIndex < 0) ) {
       message(paste("error in testIndFisher : wrong input of xIndex or csIndex"))
       results <- list(pvalue = pvalue, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash)
       return(results)
@@ -174,7 +174,7 @@ permMMFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
       }
       
       #check input validity
-      if (xIndex < 0 || csIndex < 0) {
+      if ( any(xIndex < 0) || any(csIndex < 0) ) {
         message(paste("error in testIndFisher : wrong input of xIndex or csIndex"))
         aa[[ i ]] <- list(pvalue = pvalue, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash)
       }
