@@ -12,24 +12,24 @@ testIndGEELogistic = function(target, reps = NULL, group, dataset, xIndex, csInd
   #   csIndex: the indices of the variables to condition on. They can be mixed variables, either continous or categorical
   #   this method returns: the pvalue PVALUE, the statistic STAT.
   #cast factor into numeric vector
-  target = as.numeric(as.vector(target));
+  target <- as.numeric(as.vector(target));
   csIndex[which(is.na(csIndex))] = 0
   
   if( hash )  {
-    csIndex2 = csIndex[which(csIndex!=0)]
-    csIndex2 = sort(csIndex2)
-    xcs = c(xIndex,csIndex2)
-    key = paste(as.character(xcs) , collapse=" ");
+    csIndex2 <- csIndex[which(csIndex!=0)]
+    csIndex2 <- sort(csIndex2)
+    xcs <- c(xIndex,csIndex2)
+    key <- paste(as.character(xcs) , collapse=" ");
     if( !is.null(stat_hash[key]) )  {
-      stat = stat_hash[key];
-      pvalue = pvalue_hash[key];
+      stat <- stat_hash[key];
+      pvalue <- pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
   #if the test cannot performed succesfully these are the returned values
-  pvalue = log(1);
-  stat = 0; 
+  pvalue <- log(1);
+  stat <- 0; 
   #information with respect to cs
   if ( !is.na(match(xIndex, csIndex)) )  {
     if ( hash )  {      #update hash objects
@@ -46,10 +46,12 @@ testIndGEELogistic = function(target, reps = NULL, group, dataset, xIndex, csInd
     return(results);
   }
   #extract the data
-  x = dataset[ , xIndex];
-  cs = dataset[ , csIndex];
+  x <- dataset[ , xIndex];
+  cs <- dataset[ , csIndex];
   if(length(cs) == 0 || any( is.na(cs) ) )  cs = NULL;
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
+  oop <- options(warn = -1) 
+  on.exit( options(oop) )
   if ( length(cs) != 0 )  {
     if ( is.null(dim(cs)[2]) )  {     #cs is a vector
       if ( identical(x, cs) )  {    #if(!any(x == cs) == FALSE)
@@ -73,13 +75,12 @@ testIndGEELogistic = function(target, reps = NULL, group, dataset, xIndex, csInd
       }
     }
   }
-  options(warn = -1)
   #if the conditioning set (cs) is empty, we use the t-test on the coefficient of x.
   if (length(cs) == 0)  {
     #if the univariate models have been already compute
     if ( !is.null(univariateModels) )  {
-      pvalue = univariateModels$pvalue[[xIndex]];
-      stat = univariateModels$stat[[xIndex]];
+      pvalue <- univariateModels$pvalue[[xIndex]];
+      stat <- univariateModels$stat[[xIndex]];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
